@@ -1,7 +1,7 @@
 /* For information on usage and redistribution, and for a DISCLAIMER OF ALL
 * WARRANTIES, see the file, "LICENSE.txt," in this distribution.
 
-iem_adaptfilt written by Markus Noisternig & Thomas Musil 
+iem_adaptfilt written by Markus Noisternig & Thomas Musil
 noisternig_AT_iem.at; musil_AT_iem.at
 (c) Institute of Electronic Music and Acoustics, Graz Austria 2018 */
 
@@ -18,9 +18,9 @@ static t_class *iem_adaptfilt_class;
 
 static void *iem_adaptfilt_new(void)
 {
-	t_object *x = (t_object *)pd_new(iem_adaptfilt_class);
-    
-	return (x);
+        t_object *x = (t_object *)pd_new(iem_adaptfilt_class);
+
+        return (x);
 }
 
 void NLMS_tilde_setup(void);
@@ -42,11 +42,11 @@ void iem_adaptfilt_setup(void)
   n_CLNLMS_tilde_setup();
   FXNLMSplus2in_tilde_setup();
   FXNLMSplus3in_tilde_setup();
-  	
-  	post("----------------------------------------------");
-	post("iem_adaptfilt (R-1.03) library loaded!");
-	post("(c) Markus Noisternig, Thomas Musil");
-	post("    {noisternig, musil}_AT_iem.at");
-	post("    IEM Graz, Austria, 01.2018");
-	post("----------------------------------------------");
+  
+  post("----------------------------------------------");
+  post("iem_adaptfilt (1.03) library loaded!");
+  post("   (c) Markus Noisternig, Thomas Musil");
+  post("   {noisternig, musil}_AT_iem.at");
+  post("   iem KUG Graz Austria, "BUILD_DATE);
+  post("----------------------------------------------");
 }
